@@ -1,17 +1,27 @@
 import re
 from typing import Any, Dict, List
+import os
+
 
 class Tokenize(object):
-    def __init__(self, 
-                vocab_file,
-                bpe_file,
-                pad_token = '<pad>',
-                bos_token = '<s>',
-                eos_token = '</s>',
-                mask_token = '<mask>',
-                unk_token = '<unk>') -> None:
+    def __init__(self,
+                 pad_token='<pad>',
+                 bos_token='<s>',
+                 eos_token='</s>',
+                 mask_token='<mask>',
+                 unk_token='<unk>') -> None:
         super().__init__()
 
+        abs_direct = 'genz_tokenize/data/'
+        try:
+            self.vocab_file
+        except:
+            self.vocab_file = abs_direct + 'vocab.txt'
+        try:
+            self.bpe_file
+        except:
+            self.bpe_file = abs_direct + 'bpe.codes'
+
         self.pad_token = pad_token
         self.bos_token = bos_token
         self.eos_token = eos_token
@@ -26,10 +36,10 @@ class Tokenize(object):
             self.unk_token: 4
         }
 
-        self.add_vocab_file(vocab_file)
-        self.decoder = {v:k for k, v in self.encoder.items()}
+        self.add_vocab_file(self.vocab_file)
+        self.decoder = {v: k for k, v in self.encoder.items()}
 
-        self.add_bpe_file(bpe_file)
+        self.add_bpe_file(self.bpe_file)
 
     def add_vocab_file(self, vocab_file):
         with open(vocab_file, 'r', encoding='utf-8') as f:
@@ -48,7 +58,7 @@ class Tokenize(object):
 
     def vocab_size(self):
         return len(self.encoder)
-    
+
     def bpe(self, token):
         word = tuple(token)
         word = tuple(list(word[:-1]) + [word[-1] + "</w>"])
@@ -96,9 +106,10 @@ class Tokenize(object):
         words = re.findall(r"\S+\n?", text)  # tách từ ra
 
         for token in words:
-            split_tokens.extend([t for t in self.bpe(token).split(" ")]) # kết nối các ký tự với nhau
+            # kết nối các ký tự với nhau
+            split_tokens.extend([t for t in self.bpe(token).split(" ")])
         return split_tokens  # tách từ ra
-    
+
     def __convert_token_to_ids(self, word):
         return self.encoder.get(word, self.encoder.get(self.unk_token))
 
@@ -133,16 +144,14 @@ class Tokenize(object):
         truncate = kwds.get('truncate', True)
         padding = kwds.get('padding', True)
         input_ids = []
-        mask = []
         for i in sentences:
             token = self.encode(i)
             if padding:
                 token = self.__padding(token, maxlen, truncate)
-            mask.append([1 if i!=0 else 0 for i in token])
             input_ids.append(token)
-        return {'input_ids': input_ids, 'mask': mask}
+        return input_ids
 
-    @staticmethod
+    @ staticmethod
     def get_pairs(word):
         pairs = set()
         prev_char = word[0]
@@ -151,4 +160,4 @@ class Tokenize(object):
             prev_char = char
 
         pairs = set(pairs)
-        return pairs
\ No newline at end of file
+        return pairs
